# ユーティリティモジュール

`wandas.utils` モジュールは、Wandasライブラリで使用される様々なユーティリティ機能を提供します。

## フレームデータセット

複数のデータフレームを管理するためのデータセットユーティリティを提供します。

::: wandas.utils.frame_dataset

## サンプル生成

テスト用のサンプルデータを生成する機能を提供します。

::: wandas.utils.generate_sample

## 型定義

Wandasで使用される型定義を提供します。

::: wandas.utils.types

## 一般的なユーティリティ

その他の一般的なユーティリティ関数を提供します。

::: wandas.utils.util
